@@ -53,7 +53,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.5.13'
+VERSION = '0.5.14'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -615,7 +615,7 @@ def _build_werkzeug_request_data(request):
     request_data = {
         'url': request.url,
         'GET': dict(request.args),
-        'POST': dict(request.get_json()) or dict(request.form),
+        'POST': dict(request.get_json() or request.form),
         'user_ip': _extract_user_ip(request),
         'headers': dict(request.headers),
         'method': request.method,
