@@ -9,6 +9,11 @@ class RollbarBottleReporter(object):
     api = 2
 
     def __init__(self, *args, **kwargs):
+        if 'exception_level_filters' in kwargs:
+            kwargs['exception_level_filters'].append((bottle.BaseResponse, 'ignored'))
+        else:
+            kwargs['exception_level_filters'] = [(bottle.BaseResponse, 'ignored')]
+
         rollbar.init(*args, **kwargs)
 
     def __call__(self, callback):
